#alegbra :
A PyPI package that can be used perform alegbric function .

# Installation :
Run the following to install:

'''cmd
pip install alegbra
'''

# Team :
## Contributor : Harini.T
## Mentor      : Venkateswar.S 